@@ -17,7 +17,8 @@ BUILDDIR="$(pwd)/build/tk${TCLVERS}"
 PATCHDIR="$(pwd)/patches"
 OUTDIR="$(pwd)/out"
 INSTDIR="$(pwd)/inst"
-export SRC SRCURL BUILDDIR PATCHDIR OUTDIR INSTDIR
+PATCHSCRIPTDIR="$(pwd)/patchscripts"
+export SRC SRCURL BUILDDIR PATCHDIR OUTDIR INSTDIR PATCHSCRIPTDIR
 
 rm -rf 'build' 'out' 'inst'
 mkdir 'build' 'out' 'inst' || exit 1
@@ -35,16 +36,29 @@ if [ ! -f "${SRC}" ]; then
 
 	if echo "${TCLVERS}" | grep '^cvs_' >/dev/null; then
 		CVSTAG=$(echo "${TCLVERS}" | sed 's/^cvs_//g')
+		if [ "${CVSTAG}" = "HEAD" ]; then
+			CVSTAG="trunk"
+		fi
 		export CVSTAG
 
 		(       
 			cd src || exit 1
 
-			cvs -z3 -d:pserver:anonymous@tcl.cvs.sourceforge.net:/cvsroot/tktoolkit co -r "${CVSTAG}" -P tk
+			workdir="tmp-$$${RANDOM}${RANDOM}${RANDOM}"
+			rm -rf "${workdir}"
 
-			mv tk "tk${TCLVERS}"
+			mkdir "${workdir}" || exit 1
+			cd "${workdir}" || exit 1
 
-			tar -cf - "tk${TCLVERS}" | gzip -c > "../${SRC}"
+			wget -O "tmp-tk.tar.gz" "http://core.tcl.tk/tk/tarball/tk-${CVSTAG}.tar.gz?uuid=${CVSTAG}" || rm -f 'tmp-tk.tar.gz'
+			gzip -dc "tmp-tk.tar.gz" | tar -xf -
+
+			mv "tk-${CVSTAG}" "tk${TCLVERS}"
+                        
+			tar -cf - "tk${TCLVERS}" | gzip -c > "../../${SRC}"
+
+			cd ..
+			rm -rf "${workdir}"
 		)
 	else
 		rm -f "${SRC}.tmp"
@@ -87,6 +101,17 @@ fi
 		done
 	)
 
+	# Apply patch scripts if needed
+	for patchscript in "${PATCHSCRIPTDIR}"/*.sh; do
+		if [ -f "${patchscript}" ]; then
+			echo "Running patch script: ${patchscript}"
+                                
+			(
+				. "${patchscript}"
+			)
+		fi
+	done
+
 	for dir in unix win macosx win64 __fail__; do
 		if [ "${dir}" = "__fail__" ]; then
 			exit 1
@@ -126,7 +151,17 @@ fi
 		fi
 
 		echo "Running: ${MAKE:-make}"
-		${MAKE:-make} || continue
+		${MAKE:-make} || (
+			# Workaround a bug in Tk on FreeBSD 8.1:
+			#   https://sourceforge.net/tracker/?func=detail&atid=112997&aid=3107390&group_id=12997
+			LIBTKFILE="$(ls libtk*.so.1 2>/dev/null | head -1)"
+			if [ -f "${LIBTKFILE}" ]; then
+				NEWLIBTKFILE="$(echo "${LIBTKFILE}" | sed 's@\.so\.1@.so@')"
+				cp "${LIBTKFILE}" "${NEWLIBTKFILE}"
+			fi
+
+			${MAKE:-make}
+		) || continue
 
 		echo "Running: ${MAKE:-make} install"
 		${MAKE:-make} install || continue
@@ -142,15 +177,21 @@ fi
 			fi
 		fi
 
-		# Update pkgIndex to load libtk from the local directory rather
-		# than the parent directory
-		for pkgIndex in "${INSTDIR}"/lib/tk*/pkgIndex.tcl; do
-			sed 's@ \.\. @ @g' "${pkgIndex}" > "${pkgIndex}.new"
-			mv "${pkgIndex}.new" "${pkgIndex}"
-		done
+		if [ "${STATICTK}" = "1" ]; then
+			# If we are building statically, don't create a
+			# pkgIndex.tcl
+			rm -f "${INSTDIR}"/lib/tk*/pkgIndex.tcl
+		else
+			# Update pkgIndex to load libtk from the local directory rather
+			# than the parent directory
+			for pkgIndex in "${INSTDIR}"/lib/tk*/pkgIndex.tcl; do
+				sed 's@ \.\. @ @g' "${pkgIndex}" > "${pkgIndex}.new"
+				mv "${pkgIndex}.new" "${pkgIndex}"
+			done
+		fi
 
 		mkdir "${OUTDIR}/lib" || exit 1
-		cp -r "${INSTDIR}/lib"/tk*/ "${OUTDIR}/lib/"
+		cp -r "${INSTDIR}/lib"/tk* "${OUTDIR}/lib/"
 		cp -r "${INSTDIR}/lib"/libtk* "${OUTDIR}/lib"/tk*/
 		rm -rf "${OUTDIR}/lib"/tk*/demos
 
