@@ -44,6 +44,12 @@ fi
 	AR="${AR:-ar} rcu"
 	export AR
 
+	# If we are building for KitDLL, compile with '-fPIC'
+	if [ "${KITTARGET}" = "kitdll" ]; then
+		CFLAGS="${CFLAGS} -fPIC"
+		export CFLAGS
+	fi
+
 	# We don't pass CONFIGUREEXTRA here, since this isn't a GNU autoconf
 	# script and will puke
 	echo "Running: ./configure --prefix=\"${INSTDIR}\""
